py4j.commands (py4j-java 0.10.9.7 API)

# Package py4j.commands

- Interface Summary
  Interface | Description
  --- | ---
  Command | This interface must be implemented by all commands.

- Class Summary
  Class | Description
  --- | ---
  AbstractCommand | Abstract base class for commands.
  ArrayCommand | A ArrayCommand is responsible for handling operations on arrays.
  AuthCommand | The auth command is responsible for checking that the client knows the server's auth secret.
  CallCommand | A CallCommand is responsible for parsing a call command and calling the method on the target object.
  ConstructorCommand | A ConstructorCommand is responsible for calling the constructors of a Java class.
  DirCommand |
  ExceptionCommand |
  FieldCommand | A FieldCommand is responsible for accessing and setting fields of objects.
  HelpPageCommand | A HelpPageCommand is responsible for generating a help page for a Java object or Java class.
  JVMViewCommand | A JVMViewCommand is responsible for managing JVM views: creating views, adding imports, searching for fully qualified names.
  ListCommand | A ListCommand is responsible for handling operations on lists (e.g., slicing).
  MemoryCommand | The MemoryCommand is responsible for handling garbage collection requests from the Python side, i.e., when a java object is no longer used by the Python program.
  ReflectionCommand | The ReflectionCommand is responsible for accessing packages, classes, and static members.
  ShutdownGatewayServerCommand | The ShutdownGatewayServerCommand is responsible for shutting down the GatewayServer.
  StreamCommand | A `StreamCommand` is like a `CallCommand`, but returns the value directly.